==> haskell-pango-0.13.4.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.4.0
id: pango-0.13.4.0-BnpBWs5xr8YHx5JzKQ2ZU9
key: pango-0.13.4.0-BnpBWs5xr8YHx5JzKQ2ZU9
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 4f7f0eb95ea723bf4330e4495a347b41
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.4.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/pango-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/pango-0.13.4.0
hs-libraries: HSpango-0.13.4.0-BnpBWs5xr8YHx5JzKQ2ZU9
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    base-4.10.0.0 process-1.6.1.0 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 pretty-1.1.3.3 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
    cairo-0.13.4.1-7Eg7ujN3nAn13nDgdAToR3
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             array-0.5.2.0=f1e5b16bbab6fd27896e28be963fa7eb
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             pretty-1.1.3.3=e10ebff28b4fc258fa0291d45c86289c
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz=ced89e15f6e682a876e0018c66b03858
             cairo-0.13.4.1-7Eg7ujN3nAn13nDgdAToR3=89a8a7b8bebecdd713a0898a6df96e1b
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.4.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.4.0
id: pango-0.13.4.0-Hq5i7NvaSuDEFmDFGdIwVJ
key: pango-0.13.4.0-Hq5i7NvaSuDEFmDFGdIwVJ
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 9254868f7c56fca7ffd5f9a314d0085a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pango-0.13.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/pango-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/pango-0.13.4.0
hs-libraries: HSpango-0.13.4.0-Hq5i7NvaSuDEFmDFGdIwVJ
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    base-4.10.1.0 process-1.6.1.0 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 pretty-1.1.3.3 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    glib-0.13.5.0-BGVYE4UfPO71NUSSN3P5KJ
    cairo-0.13.4.2-C3nVqfGRkpHLqRzje9lOEO
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             glib-0.13.5.0-BGVYE4UfPO71NUSSN3P5KJ=0daa0858c51dd0a9d17eb258a56832df
             cairo-0.13.4.2-C3nVqfGRkpHLqRzje9lOEO=6393a860616c369ff4e570062e1efab7
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
